# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`hiera`](#hiera): == Class: hiera  This class handles installing the hiera.yaml for Puppet's use.  === Parameters:    See README.  === Actions:  Installs eithe
* [`hiera::deep_merge`](#hieradeep_merge): == Class: hiera::deep_merge  This class installs and configures deep_merge  === Authors:  Joseph Yaworski <jyaworski@carotid.us>  === Copyrig
* [`hiera::eyaml`](#hieraeyaml): == Class: hiera::eyaml  This class installs and configures hiera-eyaml  === Authors:  Terri Haber <terri@puppetlabs.com>  === Copyright:  Cop
* [`hiera::eyaml_gpg`](#hieraeyaml_gpg): == Class hiera::eyaml_gpg  This calls install and configures hiera-eyaml-gpg
* [`hiera::params`](#hieraparams): == Class: hiera::params  This class handles OS-specific configuration of the hiera module.  It looks for variables in top scope (probably fro

### Defined types

* [`hiera::install`](#hierainstall): Private define

### Data types

* [`Hiera::Hiera5_defaults`](#hierahiera5_defaults): This will validate hiera 5 'defaults' hash
* [`Hiera::Hiera5_hierarchy`](#hierahiera5_hierarchy): This will validate hiera 5 hierarchy array hash

## Classes

### <a name="hiera"></a>`hiera`

== Class: hiera

This class handles installing the hiera.yaml for Puppet's use.

=== Parameters:

  See README.

=== Actions:

Installs either /etc/puppet/hiera.yaml or /etc/puppetlabs/puppet/hiera.yaml.
Links /etc/hiera.yaml to the above file.
Creates $datadir (if $datadir_manage == true).
Creates hiera.yaml in hiera version 5 format if hiera_version = 5 is passed to the class

=== Requires:

puppetlabs-stdlib >= 4.3.1

=== Sample Usage:

  class { 'hiera':
    hierarchy => [
      '%{environment}',
      'common',
    ],
  }

=== Sample Usage for Hiera 5:

  class { 'hiera':
    hiera_version   =>  '5',
    hiera5_defaults =>  {"datadir" => "data", "data_hash" => "yaml_data"},
    hierarchy       =>  [
                                {"name" =>  "Virtual yaml", "path"  =>  "virtual/%{virtual}.yaml"},
                                {"name" =>  "Nodes yaml", "paths" =>  ['nodes/%{trusted.certname}.yaml', 'nodes/%{osfamily}.yaml']},
                                {"name" =>  "Global yaml file", "path" =>  "common.yaml"},
                        ],
  }

Note: Please note that hiera 5 hierarchy should be an array of hash

=== Authors:

Hunter Haugen <h.haugen@gmail.com>
Mike Arnold <mike@razorsedge.org>
Terri Haber <terri@puppetlabs.com>
Greg Kitson <greg.kitson@puppetlabs.com>

=== Copyright:

Copyright (C) 2012 Hunter Haugen, unless otherwise noted.
Copyright (C) 2013 Mike Arnold, unless otherwise noted.
Copyright (C) 2014 Terri Haber, unless otherwise noted.
Copyright (C) 2016 Vox Pupuli, unless otherwise noted.

#### Parameters

The following parameters are available in the `hiera` class:

* [`hierarchy`](#hierarchy)
* [`hiera_version`](#hiera_version)
* [`hiera5_defaults`](#hiera5_defaults)
* [`backends`](#backends)
* [`backend_options`](#backend_options)
* [`hiera_yaml`](#hiera_yaml)
* [`create_symlink`](#create_symlink)
* [`datadir`](#datadir)
* [`datadir_manage`](#datadir_manage)
* [`owner`](#owner)
* [`group`](#group)
* [`mode`](#mode)
* [`eyaml_owner`](#eyaml_owner)
* [`eyaml_group`](#eyaml_group)
* [`provider`](#provider)
* [`eyaml`](#eyaml)
* [`eyaml_name`](#eyaml_name)
* [`eyaml_version`](#eyaml_version)
* [`eyaml_source`](#eyaml_source)
* [`eyaml_datadir`](#eyaml_datadir)
* [`eyaml_extension`](#eyaml_extension)
* [`confdir`](#confdir)
* [`puppet_conf_manage`](#puppet_conf_manage)
* [`logger`](#logger)
* [`cmdpath`](#cmdpath)
* [`create_keys`](#create_keys)
* [`keysdir`](#keysdir)
* [`deep_merge_name`](#deep_merge_name)
* [`deep_merge_version`](#deep_merge_version)
* [`deep_merge_source`](#deep_merge_source)
* [`deep_merge_options`](#deep_merge_options)
* [`merge_behavior`](#merge_behavior)
* [`extra_config`](#extra_config)
* [`master_service`](#master_service)
* [`manage_package`](#manage_package)
* [`manage_eyaml_package`](#manage_eyaml_package)
* [`manage_deep_merge_package`](#manage_deep_merge_package)
* [`manage_eyaml_gpg_package`](#manage_eyaml_gpg_package)
* [`package_name`](#package_name)
* [`package_ensure`](#package_ensure)
* [`eyaml_gpg_name`](#eyaml_gpg_name)
* [`eyaml_gpg_version`](#eyaml_gpg_version)
* [`eyaml_gpg_source`](#eyaml_gpg_source)
* [`eyaml_gpg`](#eyaml_gpg)
* [`eyaml_gpg_gnupghome_recurse`](#eyaml_gpg_gnupghome_recurse)
* [`eyaml_gpg_recipients`](#eyaml_gpg_recipients)
* [`eyaml_pkcs7_private_key`](#eyaml_pkcs7_private_key)
* [`eyaml_pkcs7_public_key`](#eyaml_pkcs7_public_key)
* [`ruby_gpg_name`](#ruby_gpg_name)
* [`ruby_gpg_version`](#ruby_gpg_version)
* [`ruby_gpg_source`](#ruby_gpg_source)
* [`gem_install_options`](#gem_install_options)
* [`gem_source`](#gem_source)

##### <a name="hierarchy"></a>`hierarchy`

Data type: `Variant[Array, Array[Hash]]`



Default value: `$hiera::params::hierarchy`

##### <a name="hiera_version"></a>`hiera_version`

Data type: `Optional[Enum['3','5']]`



Default value: `$hiera::params::hiera_version`

##### <a name="hiera5_defaults"></a>`hiera5_defaults`

Data type: `Hiera::Hiera5_defaults`



Default value: `$hiera::params::hiera5_defaults`

##### <a name="backends"></a>`backends`

Data type: `Any`



Default value: `['yaml']`

##### <a name="backend_options"></a>`backend_options`

Data type: `Any`



Default value: `{}`

##### <a name="hiera_yaml"></a>`hiera_yaml`

Data type: `Any`



Default value: `$hiera::params::hiera_yaml`

##### <a name="create_symlink"></a>`create_symlink`

Data type: `Any`



Default value: ``true``

##### <a name="datadir"></a>`datadir`

Data type: `Any`



Default value: `$hiera::params::datadir`

##### <a name="datadir_manage"></a>`datadir_manage`

Data type: `Any`



Default value: ``true``

##### <a name="owner"></a>`owner`

Data type: `Any`



Default value: `$hiera::params::owner`

##### <a name="group"></a>`group`

Data type: `Any`



Default value: `$hiera::params::group`

##### <a name="mode"></a>`mode`

Data type: `Any`



Default value: `$hiera::params::mode`

##### <a name="eyaml_owner"></a>`eyaml_owner`

Data type: `Any`



Default value: `$hiera::params::eyaml_owner`

##### <a name="eyaml_group"></a>`eyaml_group`

Data type: `Any`



Default value: `$hiera::params::eyaml_group`

##### <a name="provider"></a>`provider`

Data type: `Any`



Default value: `$hiera::params::provider`

##### <a name="eyaml"></a>`eyaml`

Data type: `Any`



Default value: ``false``

##### <a name="eyaml_name"></a>`eyaml_name`

Data type: `Any`



Default value: `'hiera-eyaml'`

##### <a name="eyaml_version"></a>`eyaml_version`

Data type: `Any`



Default value: ``undef``

##### <a name="eyaml_source"></a>`eyaml_source`

Data type: `Any`



Default value: ``undef``

##### <a name="eyaml_datadir"></a>`eyaml_datadir`

Data type: `Any`



Default value: ``undef``

##### <a name="eyaml_extension"></a>`eyaml_extension`

Data type: `Any`



Default value: ``undef``

##### <a name="confdir"></a>`confdir`

Data type: `Any`



Default value: `$hiera::params::confdir`

##### <a name="puppet_conf_manage"></a>`puppet_conf_manage`

Data type: `Any`



Default value: ``true``

##### <a name="logger"></a>`logger`

Data type: `Any`



Default value: `'console'`

##### <a name="cmdpath"></a>`cmdpath`

Data type: `Any`



Default value: `$hiera::params::cmdpath`

##### <a name="create_keys"></a>`create_keys`

Data type: `Any`



Default value: ``true``

##### <a name="keysdir"></a>`keysdir`

Data type: `Any`



Default value: ``undef``

##### <a name="deep_merge_name"></a>`deep_merge_name`

Data type: `Any`



Default value: `'deep_merge'`

##### <a name="deep_merge_version"></a>`deep_merge_version`

Data type: `Any`



Default value: ``undef``

##### <a name="deep_merge_source"></a>`deep_merge_source`

Data type: `Any`



Default value: ``undef``

##### <a name="deep_merge_options"></a>`deep_merge_options`

Data type: `Any`



Default value: `{}`

##### <a name="merge_behavior"></a>`merge_behavior`

Data type: `Any`



Default value: ``undef``

##### <a name="extra_config"></a>`extra_config`

Data type: `Any`



Default value: `''`

##### <a name="master_service"></a>`master_service`

Data type: `Any`



Default value: `$hiera::params::master_service`

##### <a name="manage_package"></a>`manage_package`

Data type: `Any`



Default value: `$hiera::params::manage_package`

##### <a name="manage_eyaml_package"></a>`manage_eyaml_package`

Data type: `Boolean`



Default value: ``true``

##### <a name="manage_deep_merge_package"></a>`manage_deep_merge_package`

Data type: `Boolean`



Default value: ``true``

##### <a name="manage_eyaml_gpg_package"></a>`manage_eyaml_gpg_package`

Data type: `Boolean`



Default value: ``true``

##### <a name="package_name"></a>`package_name`

Data type: `Any`



Default value: `$hiera::params::package_name`

##### <a name="package_ensure"></a>`package_ensure`

Data type: `Any`



Default value: `$hiera::params::package_ensure`

##### <a name="eyaml_gpg_name"></a>`eyaml_gpg_name`

Data type: `Any`



Default value: `'hiera-eyaml-gpg'`

##### <a name="eyaml_gpg_version"></a>`eyaml_gpg_version`

Data type: `Any`



Default value: ``undef``

##### <a name="eyaml_gpg_source"></a>`eyaml_gpg_source`

Data type: `Any`



Default value: ``undef``

##### <a name="eyaml_gpg"></a>`eyaml_gpg`

Data type: `Any`



Default value: ``false``

##### <a name="eyaml_gpg_gnupghome_recurse"></a>`eyaml_gpg_gnupghome_recurse`

Data type: `Boolean`



Default value: ``true``

##### <a name="eyaml_gpg_recipients"></a>`eyaml_gpg_recipients`

Data type: `Any`



Default value: ``undef``

##### <a name="eyaml_pkcs7_private_key"></a>`eyaml_pkcs7_private_key`

Data type: `Any`



Default value: ``undef``

##### <a name="eyaml_pkcs7_public_key"></a>`eyaml_pkcs7_public_key`

Data type: `Any`



Default value: ``undef``

##### <a name="ruby_gpg_name"></a>`ruby_gpg_name`

Data type: `Any`



Default value: `'ruby_gpg'`

##### <a name="ruby_gpg_version"></a>`ruby_gpg_version`

Data type: `Any`



Default value: ``undef``

##### <a name="ruby_gpg_source"></a>`ruby_gpg_source`

Data type: `Any`



Default value: ``undef``

##### <a name="gem_install_options"></a>`gem_install_options`

Data type: `Optional[Array]`



Default value: ``undef``

##### <a name="gem_source"></a>`gem_source`

Data type: `Any`



Default value: ``undef``

### <a name="hieradeep_merge"></a>`hiera::deep_merge`

== Class: hiera::deep_merge

This class installs and configures deep_merge

=== Authors:

Joseph Yaworski <jyaworski@carotid.us>

=== Copyright:

Copyright (C) 2016 Joseph Yaworski, unless otherwise noted.

### <a name="hieraeyaml"></a>`hiera::eyaml`

== Class: hiera::eyaml

This class installs and configures hiera-eyaml

=== Authors:

Terri Haber <terri@puppetlabs.com>

=== Copyright:

Copyright (C) 2014 Terri Haber, unless otherwise noted.

### <a name="hieraeyaml_gpg"></a>`hiera::eyaml_gpg`

== Class hiera::eyaml_gpg

This calls install and configures hiera-eyaml-gpg

### <a name="hieraparams"></a>`hiera::params`

== Class: hiera::params

This class handles OS-specific configuration of the hiera module.  It
looks for variables in top scope (probably from an ENC such as Dashboard).  If
the variable doesn't exist in top scope, it falls back to a hard coded default
value.

=== Authors:

Mike Arnold <mike@razorsedge.org>

=== Copyright:

Copyright (C) 2013 Mike Arnold, unless otherwise noted.

## Defined types

### <a name="hierainstall"></a>`hiera::install`

Private define

#### Parameters

The following parameters are available in the `hiera::install` defined type:

* [`gem_name`](#gem_name)
* [`provider`](#provider)
* [`gem_version`](#gem_version)
* [`gem_source`](#gem_source)
* [`gem_install_options`](#gem_install_options)

##### <a name="gem_name"></a>`gem_name`

Data type: `Any`



##### <a name="provider"></a>`provider`

Data type: `Any`



##### <a name="gem_version"></a>`gem_version`

Data type: `Any`



Default value: ``undef``

##### <a name="gem_source"></a>`gem_source`

Data type: `Any`



Default value: ``undef``

##### <a name="gem_install_options"></a>`gem_install_options`

Data type: `Any`



Default value: `$hiera::gem_install_options`

## Data types

### <a name="hierahiera5_defaults"></a>`Hiera::Hiera5_defaults`

This will validate hiera 5 'defaults' hash

Alias of

```puppet
Struct[{
                                datadir        => Optional[String],
                                data_hash      => Optional[Enum['yaml_data', 'json_data', 'hocon_data']],
                                lookup_key     => Optional[String],
                                data_dig       => Optional[String],
                                hiera3_backend => Optional[String],
                                options        => Optional[Hash],
                              }]
```

### <a name="hierahiera5_hierarchy"></a>`Hiera::Hiera5_hierarchy`

This will validate hiera 5 hierarchy array hash

Alias of

```puppet
Array[Struct[{
                                  name            => String,
                                  path            => Optional[String],
                                  paths           => Optional[Array[String]],
                                  glob            => Optional[String],
                                  globs           => Optional[Array[String]],
                                  uri             => Optional[String],
                                  uris            => Optional[Array[String]],
                                  data_hash       => Optional[String],
                                  lookup_key      => Optional[String],
                                  data_dig        => Optional[String],
                                  datadir         => Optional[String],
                                  hiera3_backend  => Optional[String],
                                  options         => Optional[Hash],
                                }]]
```

